@@ -1157,7 +1157,7 @@ def test_install_nonlocal_compatible_wheel(
         "--find-links",
         data.find_links,
         "--only-binary=:all:",
-        "--python",
+        "--python-version",
         "3",
         "--platform",
         "fakeplat",
@@ -1177,7 +1177,7 @@ def test_install_nonlocal_compatible_wheel(
         "--find-links",
         data.find_links,
         "--only-binary=:all:",
-        "--python",
+        "--python-version",
         "3",
         "--platform",
         "fakeplat",
