@@ -7,8 +7,12 @@ from pathlib import Path
 
 import pytest
 
-from tests.lib import pyversion  # noqa: F401
-from tests.lib import PipTestEnvironment, TestData, assert_all_changes
+from tests.lib import (
+    PipTestEnvironment,
+    TestData,
+    assert_all_changes,
+    pyversion,  # noqa: F401
+)
 
 
 @pytest.mark.network
