@@ -2,7 +2,6 @@ import logging
 import os
 from pathlib import Path
 from typing import Optional, cast
-from unittest import mock
 
 import pytest
 
@@ -58,63 +57,42 @@ class ReqMock:
 
 
 @pytest.mark.parametrize(
-    "req, disallow_bdist_wheel, expected",
+    "req, expected",
     [
-        # When binaries are allowed, we build.
-        (ReqMock(use_pep517=True), False, True),
-        (ReqMock(use_pep517=False), False, True),
-        # When binaries are disallowed, we don't build, unless pep517 is
-        # enabled.
-        (ReqMock(use_pep517=True), True, True),
-        (ReqMock(use_pep517=False), True, False),
+        # We build, whether pep 517 is enabled or not.
+        (ReqMock(use_pep517=True), True),
+        (ReqMock(use_pep517=False), True),
         # We don't build constraints.
-        (ReqMock(constraint=True), False, False),
+        (ReqMock(constraint=True), False),
         # We don't build reqs that are already wheels.
-        (ReqMock(is_wheel=True), False, False),
-        (ReqMock(editable=True, use_pep517=False), False, False),
+        (ReqMock(is_wheel=True), False),
+        # We build editables if the backend supports PEP 660.
+        (ReqMock(editable=True, use_pep517=False), False),
         (
             ReqMock(editable=True, use_pep517=True, supports_pyproject_editable=True),
-            False,
             True,
         ),
         (
             ReqMock(editable=True, use_pep517=True, supports_pyproject_editable=False),
             False,
-            False,
         ),
-        (ReqMock(source_dir=None), False, False),
+        # We don't build if there is no source dir (whatever that means!).
+        (ReqMock(source_dir=None), False),
         # By default (i.e. when binaries are allowed), VCS requirements
         # should be built in install mode.
         (
             ReqMock(link=Link("git+https://g.c/org/repo"), use_pep517=True),
-            False,
-            True,
-        ),
-        (
-            ReqMock(link=Link("git+https://g.c/org/repo"), use_pep517=False),
-            False,
-            True,
-        ),
-        # Disallowing binaries, however, should cause them not to be built.
-        # unless pep517 is enabled.
-        (
-            ReqMock(link=Link("git+https://g.c/org/repo"), use_pep517=True),
-            True,
             True,
         ),
         (
             ReqMock(link=Link("git+https://g.c/org/repo"), use_pep517=False),
             True,
-            False,
         ),
     ],
 )
-def test_should_build_for_install_command(
-    req: ReqMock, disallow_bdist_wheel: bool, expected: bool
-) -> None:
+def test_should_build_for_install_command(req: ReqMock, expected: bool) -> None:
     should_build = wheel_builder.should_build_for_install_command(
         cast(InstallRequirement, req),
-        check_bdist_wheel_allowed=lambda req: not disallow_bdist_wheel,
     )
     assert should_build is expected
 
@@ -138,28 +116,6 @@ def test_should_build_for_wheel_command(req: ReqMock, expected: bool) -> None:
     assert should_build is expected
 
 
-@mock.patch("pip._internal.wheel_builder.is_wheel_installed")
-def test_should_build_legacy_wheel_not_installed(is_wheel_installed: mock.Mock) -> None:
-    is_wheel_installed.return_value = False
-    legacy_req = ReqMock(use_pep517=False)
-    should_build = wheel_builder.should_build_for_install_command(
-        cast(InstallRequirement, legacy_req),
-        check_bdist_wheel_allowed=lambda req: True,
-    )
-    assert not should_build
-
-
-@mock.patch("pip._internal.wheel_builder.is_wheel_installed")
-def test_should_build_legacy_wheel_installed(is_wheel_installed: mock.Mock) -> None:
-    is_wheel_installed.return_value = True
-    legacy_req = ReqMock(use_pep517=False)
-    should_build = wheel_builder.should_build_for_install_command(
-        cast(InstallRequirement, legacy_req),
-        check_bdist_wheel_allowed=lambda req: True,
-    )
-    assert should_build
-
-
 @pytest.mark.parametrize(
     "req, expected",
     [
